@@ -72,7 +72,7 @@ PG-REX standby start tool
 This is executed on the node that will start as a standby.
 
 Usage:
-  pg-rex_slave_start [-n][-f][-c][-s][-h][-v]
+  pg-rex_slave_start [-n][-f][-c][-s][-o OPTIONS][-h][-v]
 
 Options:
   -n, --nobasebackup              start without taking a base backup from master
@@ -80,6 +80,8 @@ Options:
   -c, --check-only                execute until confirmation of database cluster
                                   state
   -s, --shared-archive-directory  Specify state that archive directory is shared
+  -o, --options=OPTIONS           command line options for internally executed
+                                  pg_basebackup
   -h, --help                      show this help, then exit
   -v, --version                   show this version, then exit
 
