@@ -75,7 +75,7 @@ PG-REX を Slave として起動するツールです
 Slave として起動したいノードで実行します
 
 Usage:
-  pg-rex_slave_start [-n] [-f] [-c] [-s] [-h] [-v]
+  pg-rex_slave_start [-n] [-f] [-c] [-s] [-o OPTIONS] [-h] [-v]
 
 Options:
   -n, --nobasebackup              Master からベースバックアップを取得せずに
@@ -84,6 +84,8 @@ Options:
   -c, --check-only                DB クラスタの状態確認までを実施します
   -s, --shared-archive-directory  Master と Slave でアーカイブディレクトリを
                                   共有していることを指定します
+  -o, --options=OPTIONS           ベースバックアップ取得時に実行する
+                                  pg_basebackupに渡すオプションを指定します
   -h, --help                      Usage を表示して終了します
   -v, --version                   バージョン情報を表示して終了します
 
