@@ -44,7 +44,7 @@ struct Pg_dir_state => {
 };
 
 use constant {
-    VERSIONNUM       => "1.6.1",
+    VERSIONNUM       => "1.7.0",
     VERSIONINFO      => "[0] (pg-rex_operation_tools) [1]\n",
     CONFIG_PATH      => "/etc/",
     CONFIG_FILENAME  => "pg-rex_tools.conf",
@@ -443,7 +443,7 @@ sub read_cib{
     my $my_node;
     my $my_node_id;
     my $my_pgsql_data_status_id;
-    my @check_key_list = ("pgdata", "master_ip", "repuser");
+    my @check_key_list = ("pgdata", "repuser");
     my $config_comment = "# この設定値はツールが自動で追加したものです。設定行が複数行出る場合がありますが動作に影響はありません。";
     my $result;
     my $param_name;
@@ -471,7 +471,9 @@ sub read_cib{
             if ($line =~ /\s+value=\"([^\"]+)\"\s+/){
                 $param_value = $1;
             }
-            $cib_value{$param_name} = $param_value;
+            if ($param_name && $param_value) {
+                $cib_value{$param_name} = $param_value;
+            }
 
         }
         # node id format : 
@@ -516,6 +518,7 @@ sub read_config{
     $config_value{'VIP_SLAVE'} = "enable";
     $config_value{'PEER_NODE_SSH_PASS_MODE'} = "manual";
     $config_value{'BACKUP_NODE_SSH_PASS_MODE'} = "manual";
+    $config_value{'PG_BASEBACKUP_opt'} = "-X stream";
     
     open (FILE, $config_path) or printlog("ERROR", COMMON_MS0024, $config_path);
     @config_strings = <FILE>;
